==> chainwallet-1.0.2.tar.gz: lib/src/core/serialized/BinaryParser.dart <==

import 'dart:ffi';
import 'dart:typed_data';

import "./BytesSink.dart";
import "./ByteList.dart";
import "./SerializedType.dart";
import "../fields/Field.dart";
import "../fields/Type.dart";
import 'package:chainwallet/src/utils/Util.dart';

class BinaryParser {

  int size;
  Uint8List bytes;
  int cursor = 0;


  BinaryParser(Uint8List bytes) {


    this.size = bytes.length;
    this.bytes = bytes;
  }

  BinaryParserFromHex(String hex) {
    Uint8List byteLst = Util.createUint8ListFromHexString(hex);
    this.size = byteLst.length;
    this.bytes = byteLst;
  }


  void skip(int n) {
    cursor += n;
  }

  int readOne() {
    return bytes[cursor++] ;
  }

  Uint8List read(int n) {
    Uint8List ret = new Uint8List(n);
    Util.arraycopy(bytes, cursor, ret, 0, n);
    cursor += n;
    return ret;
  }

  Field readField() {
    int fieldCode = readFieldCode();

    Field field = Field.fromCode(fieldCode);
    if (field == null) {
      throw new Exception("Couldn't parse field from " +
          fieldCode.toRadixString(16));
    }

    return field;
  }


  int readFieldCode() {
    int tagByte = readOne();

    int typeBits = (tagByte & 0xFF) >> 4;
    if (typeBits == 0) typeBits = readOne();

    int fieldBits = tagByte & 0x0F;
    if (fieldBits == 0) fieldBits = readOne();

    return (typeBits << 16 | fieldBits);
  }

  int readOneInt() {
    return readOne() & 0xFF;
  }

  int pos() {
    return cursor;
  }


  int readVLLength() {
    int b1 = readOneInt();
    int result;

    if (b1 <= 192) {
      result = b1;
    } else if (b1 <= 240) {
      int b2 = readOneInt();
      result = 193 + (b1 - 193) * 256 + b2;
    } else if (b1 <= 254) {
      int b2 = readOneInt();
      int b3 = readOneInt();
      result = 12481 + (b1 - 241) * 65536 + b2 * 256 + b3;
    } else {
      throw new Exception("Invalid varint length indicator");
    }

    return result;
  }


  bool endDefault() {
    return cursor >= size; // greater guard against infinite loops
  }


  int getSize()  => size;


  bool end(int customEnd) {
    return cursor >= size || customEnd != null && cursor >= customEnd;
  }


}

==> chainwallet-1.0.4.tar.gz: lib/src/core/serialized/BinaryParser.dart <==
import 'dart:ffi';
import 'dart:typed_data';

import "./BytesSink.dart";
import "./ByteList.dart";
import "./SerializedType.dart";
import "../fields/Field.dart";
import "../fields/Type.dart";
import 'package:chainwallet/src/utils/Util.dart';

class BinaryParser {
  int size;
  Uint8List bytes;
  int cursor = 0;

  BinaryParser(Uint8List bytes) {
    this.size = bytes.length;
    this.bytes = bytes;
  }

  BinaryParserFromHex(String hex) {
    Uint8List byteLst = Util.createUint8ListFromHexString(hex);
    this.size = byteLst.length;
    this.bytes = byteLst;
  }

  void skip(int n) {
    cursor += n;
  }

  int readOne() {
    return bytes[cursor++];
  }

  Uint8List read(int n) {
    Uint8List ret = new Uint8List(n);
    Util.arraycopy(bytes, cursor, ret, 0, n);
    cursor += n;
    return ret;
  }

  Field readField() {
    int fieldCode = readFieldCode();

    Field field = Field.fromCode(fieldCode);
    if (field == null) {
      throw new Exception(
          "Couldn't parse field from " + fieldCode.toRadixString(16));
    }

    return field;
  }

  int readFieldCode() {
    int tagByte = readOne();

    int typeBits = (tagByte & 0xFF) >> 4;
    if (typeBits == 0) typeBits = readOne();

    int fieldBits = tagByte & 0x0F;
    if (fieldBits == 0) fieldBits = readOne();

    return (typeBits << 16 | fieldBits);
  }

  int readOneInt() {
    return readOne() & 0xFF;
  }

  int pos() {
    return cursor;
  }

  int readVLLength() {
    int b1 = readOneInt();
    int result;

    if (b1 <= 192) {
      result = b1;
    } else if (b1 <= 240) {
      int b2 = readOneInt();
      result = 193 + (b1 - 193) * 256 + b2;
    } else if (b1 <= 254) {
      int b2 = readOneInt();
      int b3 = readOneInt();
      result = 12481 + (b1 - 241) * 65536 + b2 * 256 + b3;
    } else {
      throw new Exception("Invalid varint length indicator");
    }

    return result;
  }

  bool endDefault() {
    return cursor >= size; // greater guard against infinite loops
  }

  int getSize() => size;

  bool end(int customEnd) {
    return cursor >= size || customEnd != null && cursor >= customEnd;
  }
}
